==> sqlitestudio-3.1.1.tar.gz: Plugins/HtmlExport/HtmlExport_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>HtmlExport</name>
    <message>
        <location filename="htmlexport.cpp" line="46"/>
        <source>SQL query results</source>
        <translation>Реузльтаты запроса SQL</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="78"/>
        <location filename="htmlexport.cpp" line="155"/>
        <source>no type</source>
        <translation>без типа</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="115"/>
        <location filename="htmlexport.cpp" line="243"/>
        <source>Exported table: %1</source>
        <translation>Экспортированная таблица: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="127"/>
        <location filename="htmlexport.cpp" line="255"/>
        <source>Table: %1</source>
        <translation>Таблица: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="255"/>
        <source>virtual</source>
        <translation>виртуальная</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="308"/>
        <source>Exported database: %1</source>
        <translation>Экспортированная база данных: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="324"/>
        <source>Index: %1</source>
        <translation>Индекс: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="330"/>
        <source>For table:</source>
        <translation>Для таблицы:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="337"/>
        <source>Unique:</source>
        <translation>Уникальный:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="344"/>
        <source>Column</source>
        <translation>Столбец</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="345"/>
        <source>Collating</source>
        <translation>Сравнение</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="346"/>
        <source>Sort order</source>
        <translation>Порядок сортировки</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="380"/>
        <source>Trigger: %1</source>
        <translation>Триггер: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="386"/>
        <source>Activated:</source>
        <translation>Активирован:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="394"/>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="401"/>
        <source>On view:</source>
        <translation>Для представления:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="403"/>
        <source>On table:</source>
        <translation>Для таблицы:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="414"/>
        <source>Activate condition:</source>
        <translation>Условие активации:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="421"/>
        <source>Code executed:</source>
        <translation>Исполненный код:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="455"/>
        <source>View: %1</source>
        <translation>Представление: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="480"/>
        <source>Document generated by SQLiteStudio v%1 on %2</source>
        <translation>Документ сгенерирован с помощью SQLiteStudio v%1 в %2</translation>
    </message>
</context>
<context>
    <name>HtmlExportConfig</name>
    <message>
        <location filename="htmlexport.ui" line="36"/>
        <source>Maximum number of characters per cell:</source>
        <translation>Максимальное количество символов в ячейке:</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="43"/>
        <source>Include data types in first row</source>
        <translation>Включить типы данных в первую строку</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="53"/>
        <source>Column names as first row</source>
        <translation>Имена столбцов в первой строке</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="63"/>
        <source>Row numbers as first column</source>
        <translation>Номера строк в первом столбце</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="73"/>
        <source>Output format</source>
        <translation>Выходной формат</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="79"/>
        <source>Format document (new lines, indentation)</source>
        <translation>Форматировать документ (переносы строк, отступы)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="92"/>
        <source>Compress (everything in one line)</source>
        <translation>Сжать (всё в одну строку)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="108"/>
        <source>&lt;p&gt;When enabled, HTML characters such as &amp;lt;, &amp;gt; and &amp;amp; are not escaped in exported values. This allows you for example to export hyper-link enabled documents, but it also may result in incorrect HTML document (unmatched pairs of &amp;lt; and &amp;gt; characters). Be warned.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Когда опция активирована, символы HTML, такие как &amp;lt;, &amp;gt; и &amp;amp;, не экранируются в экспортируемых значениях. Это позволяет, к примеру, создавать документы со ссылками, но также может привести к порче документа HTML (при незакрытых символах &amp;lt; и &amp;gt;). Будьте внимательны.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="111"/>
        <source>Don&apos;t escape HTML characters</source>
        <translation>Не экранировать символы HTML</translation>
    </message>
</context>
</TS>

==> sqlitestudio-3.2.1.tar.gz: Plugins/HtmlExport/HtmlExport_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>HtmlExport</name>
    <message>
        <location filename="htmlexport.cpp" line="46"/>
        <source>SQL query results</source>
        <translation type="unfinished">Результаты запроса SQL</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="78"/>
        <location filename="htmlexport.cpp" line="155"/>
        <source>no type</source>
        <translation>без типа</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="115"/>
        <location filename="htmlexport.cpp" line="243"/>
        <source>Exported table: %1</source>
        <translation>Экспортированная таблица: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="127"/>
        <location filename="htmlexport.cpp" line="255"/>
        <source>Table: %1</source>
        <translation>Таблица: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="255"/>
        <source>virtual</source>
        <translation>виртуальная</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="308"/>
        <source>Exported database: %1</source>
        <translation>Экспортированная база данных: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="324"/>
        <source>Index: %1</source>
        <translation>Индекс: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="330"/>
        <source>For table:</source>
        <translation>Для таблицы:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="337"/>
        <source>Unique:</source>
        <translation>Уникальный:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="344"/>
        <source>Column</source>
        <translation>Столбец</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="345"/>
        <source>Collating</source>
        <translation>Сравнение</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="346"/>
        <source>Sort order</source>
        <translation>Порядок сортировки</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="380"/>
        <source>Trigger: %1</source>
        <translation>Триггер: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="386"/>
        <source>Activated:</source>
        <translation>Активирован:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="394"/>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="401"/>
        <source>On view:</source>
        <translation>Для представления:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="403"/>
        <source>On table:</source>
        <translation>Для таблицы:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="414"/>
        <source>Activate condition:</source>
        <translation>Условие активации:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="421"/>
        <source>Code executed:</source>
        <translation>Исполненный код:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="455"/>
        <source>View: %1</source>
        <translation>Представление: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="480"/>
        <source>Document generated by SQLiteStudio v%1 on %2</source>
        <translation>Документ сгенерирован с помощью SQLiteStudio v%1 в %2</translation>
    </message>
</context>
<context>
    <name>HtmlExportConfig</name>
    <message>
        <location filename="htmlexport.ui" line="36"/>
        <source>Maximum number of characters per cell:</source>
        <translation>Максимальное количество символов в ячейке:</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="43"/>
        <source>Include data types in first row</source>
        <translation>Включить типы данных в первую строку</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="53"/>
        <source>Column names as first row</source>
        <translation>Имена столбцов в первой строке</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="63"/>
        <source>Row numbers as first column</source>
        <translation>Номера строк в первом столбце</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="73"/>
        <source>Output format</source>
        <translation>Выходной формат</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="79"/>
        <source>Format document (new lines, indentation)</source>
        <translation>Форматировать документ (переносы строк, отступы)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="92"/>
        <source>Compress (everything in one line)</source>
        <translation>Сжать (всё в одну строку)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="108"/>
        <source>&lt;p&gt;When enabled, HTML characters such as &amp;lt;, &amp;gt; and &amp;amp; are not escaped in exported values. This allows you for example to export hyper-link enabled documents, but it also may result in incorrect HTML document (unmatched pairs of &amp;lt; and &amp;gt; characters). Be warned.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Когда опция активирована, символы HTML, такие как &amp;lt;, &amp;gt; и &amp;amp;, не экранируются в экспортируемых значениях. Это позволяет, к примеру, создавать документы со ссылками, но также может привести к порче документа HTML (при незакрытых символах &amp;lt; и &amp;gt;). Будьте внимательны.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="111"/>
        <source>Don&apos;t escape HTML characters</source>
        <translation>Не экранировать символы HTML</translation>
    </message>
</context>
</TS>
